@@ -38,6 +38,7 @@ macro_rules! pid_decl {
     ($typ:ty) => {
         #[doc = include_str!("../md_doc/pid.md")]
         #[derive(Clone, Copy, Debug, Hash, PartialEq, Eq, PartialOrd, Ord)]
+        #[repr(transparent)]
         pub struct Pid(pub(crate) $typ);
 
         impl From<$typ> for Pid {
@@ -45,6 +46,14 @@ macro_rules! pid_decl {
                 Self(v)
             }
         }
+        #[allow(clippy::from_over_into)]
+        // This Into implementation is required otherwise it seems you can't do `pid.into()`
+        // for some reasons...
+        impl Into<$typ> for Pid {
+            fn into(self) -> $typ {
+                self.0
+            }
+        }
         impl PidExt<$typ> for Pid {
             fn as_u32(self) -> u32 {
                 self.0 as u32
