@@ -9,21 +9,8 @@
 #![allow(renamed_and_removed_lints)]
 #![allow(unknown_lints)]
 
-#[cfg(feature = "debug")]
-#[doc(hidden)]
-#[allow(unused)]
-macro_rules! sysinfo_debug {
-    ($($x:tt)*) => {{
-        eprintln!($($x)*);
-    }}
-}
-
-#[cfg(not(feature = "debug"))]
-#[doc(hidden)]
-#[allow(unused)]
-macro_rules! sysinfo_debug {
-    ($($x:tt)*) => {{}};
-}
+#[macro_use]
+mod macros;
 
 cfg_if::cfg_if! {
     if #[cfg(feature = "unknown-ci")] {
@@ -72,7 +59,7 @@ cfg_if::cfg_if! {
 }
 
 pub use common::{
-    get_current_pid, AsU32, DiskType, DiskUsage, Gid, LoadAvg, NetworksIter, Pid,
+    get_current_pid, DiskType, DiskUsage, Gid, LoadAvg, NetworksIter, Pid, PidExt,
     ProcessRefreshKind, ProcessStatus, RefreshKind, Signal, Uid, User,
 };
 pub use sys::{Component, Disk, NetworkData, Networks, Process, Processor, System};
@@ -141,6 +128,52 @@ pub fn set_open_files_limit(mut _new_limit: isize) -> bool {
     }
 }
 
+// FIXME: Can be removed once negative trait bounds are supported.
+#[cfg(doctest)]
+mod doctest {
+    /// Check that `Process` doesn't implement `Clone`.
+    ///
+    /// First we check that the "basic" code works:
+    ///
+    /// ```no_run
+    /// use sysinfo::{Process, System, SystemExt};
+    ///
+    /// let mut s = System::new_all();
+    /// let p: &Process = s.processes().values().next().unwrap();
+    /// ```
+    ///
+    /// And now we check if it fails when we try to clone it:
+    ///
+    /// ```compile_fail
+    /// use sysinfo::{Process, System, SystemExt};
+    ///
+    /// let mut s = System::new_all();
+    /// let p: &Process = s.processes().values().next().unwrap();
+    /// let p = (*p).clone();
+    /// ```
+    mod process_clone {}
+
+    /// Check that `System` doesn't implement `Clone`.
+    ///
+    /// First we check that the "basic" code works:
+    ///
+    /// ```no_run
+    /// use sysinfo::{Process, System, SystemExt};
+    ///
+    /// let s = System::new();
+    /// ```
+    ///
+    /// And now we check if it fails when we try to clone it:
+    ///
+    /// ```compile_fail
+    /// use sysinfo::{Process, System, SystemExt};
+    ///
+    /// let s = System::new();
+    /// let s = s.clone();
+    /// ```
+    mod system_clone {}
+}
+
 #[cfg(test)]
 mod test {
     use crate::*;
@@ -353,4 +386,19 @@ mod test {
         }
         assert!(s.physical_core_count().unwrap_or(0) <= s.processors().len());
     }
+
+    #[test]
+    fn check_nb_supported_signals() {
+        if System::IS_SUPPORTED {
+            assert!(
+                !System::SUPPORTED_SIGNALS.is_empty(),
+                "SUPPORTED_SIGNALS shoudn't be empty on supported systems!"
+            );
+        } else {
+            assert!(
+                System::SUPPORTED_SIGNALS.is_empty(),
+                "SUPPORTED_SIGNALS should be empty on not support systems!"
+            );
+        }
+    }
 }
