@@ -10,7 +10,7 @@ use std::str::FromStr;
 
 use libc::{gid_t, kill, uid_t};
 
-use crate::sys::system::REMAINING_FILES;
+use crate::sys::system::{SystemInfo, REMAINING_FILES};
 use crate::sys::utils::{get_all_data, get_all_data_from_file, realpath};
 use crate::utils::into_iter;
 use crate::{DiskUsage, Pid, ProcessExt, ProcessRefreshKind, ProcessStatus, Signal};
@@ -82,6 +82,7 @@ pub struct Process {
     stime: u64,
     old_utime: u64,
     old_stime: u64,
+    start_time_without_boot_time: u64,
     start_time: u64,
     run_time: u64,
     pub(crate) updated: bool,
@@ -101,7 +102,12 @@ pub struct Process {
 }
 
 impl Process {
-    pub(crate) fn new(pid: Pid, parent: Option<Pid>, start_time: u64) -> Process {
+    pub(crate) fn new(
+        pid: Pid,
+        parent: Option<Pid>,
+        start_time_without_boot_time: u64,
+        info: &SystemInfo,
+    ) -> Process {
         Process {
             name: String::with_capacity(20),
             pid,
@@ -119,12 +125,13 @@ impl Process {
             old_utime: 0,
             old_stime: 0,
             updated: true,
-            start_time,
+            start_time_without_boot_time,
+            start_time: start_time_without_boot_time + info.boot_time,
             run_time: 0,
             uid: 0,
             gid: 0,
             status: ProcessStatus::Unknown(0),
-            tasks: if pid == 0 {
+            tasks: if pid.0 == 0 {
                 HashMap::with_capacity(1000)
             } else {
                 HashMap::new()
@@ -139,46 +146,9 @@ impl Process {
 }
 
 impl ProcessExt for Process {
-    fn kill(&self) -> bool {
-        self.kill_with(Signal::Kill).unwrap()
-    }
-
     fn kill_with(&self, signal: Signal) -> Option<bool> {
-        let c_signal = match signal {
-            Signal::Hangup => libc::SIGHUP,
-            Signal::Interrupt => libc::SIGINT,
-            Signal::Quit => libc::SIGQUIT,
-            Signal::Illegal => libc::SIGILL,
-            Signal::Trap => libc::SIGTRAP,
-            Signal::Abort => libc::SIGABRT,
-            Signal::IOT => libc::SIGIOT,
-            Signal::Bus => libc::SIGBUS,
-            Signal::FloatingPointException => libc::SIGFPE,
-            Signal::Kill => libc::SIGKILL,
-            Signal::User1 => libc::SIGUSR1,
-            Signal::Segv => libc::SIGSEGV,
-            Signal::User2 => libc::SIGUSR2,
-            Signal::Pipe => libc::SIGPIPE,
-            Signal::Alarm => libc::SIGALRM,
-            Signal::Term => libc::SIGTERM,
-            Signal::Child => libc::SIGCHLD,
-            Signal::Continue => libc::SIGCONT,
-            Signal::Stop => libc::SIGSTOP,
-            Signal::TSTP => libc::SIGTSTP,
-            Signal::TTIN => libc::SIGTTIN,
-            Signal::TTOU => libc::SIGTTOU,
-            Signal::Urgent => libc::SIGURG,
-            Signal::XCPU => libc::SIGXCPU,
-            Signal::XFSZ => libc::SIGXFSZ,
-            Signal::VirtualAlarm => libc::SIGVTALRM,
-            Signal::Profiling => libc::SIGPROF,
-            Signal::Winch => libc::SIGWINCH,
-            Signal::IO => libc::SIGIO,
-            Signal::Poll => libc::SIGPOLL,
-            Signal::Power => libc::SIGPWR,
-            Signal::Sys => libc::SIGSYS,
-        };
-        unsafe { Some(kill(self.pid, c_signal) == 0) }
+        let c_signal = super::system::convert_signal(signal)?;
+        unsafe { Some(kill(self.pid.0, c_signal) == 0) }
     }
 
     fn name(&self) -> &str {
@@ -257,7 +227,7 @@ impl Drop for Process {
     }
 }
 
-pub fn compute_cpu_usage(p: &mut Process, total_time: f32, max_value: f32) {
+pub(crate) fn compute_cpu_usage(p: &mut Process, total_time: f32, max_value: f32) {
     // First time updating the values without reference, wait for a second cycle to update cpu_usage
     if p.old_utime == 0 && p.old_stime == 0 {
         return;
@@ -272,7 +242,7 @@ pub fn compute_cpu_usage(p: &mut Process, total_time: f32, max_value: f32) {
         .min(max_value);
 }
 
-pub fn set_time(p: &mut Process, utime: u64, stime: u64) {
+pub(crate) fn set_time(p: &mut Process, utime: u64, stime: u64) {
     p.old_utime = p.utime;
     p.old_stime = p.stime;
     p.utime = utime;
@@ -330,10 +300,9 @@ unsafe impl<'a, T> Sync for Wrap<'a, T> {}
 pub(crate) fn _get_process_data(
     path: &Path,
     proc_list: &mut Process,
-    page_size_kb: u64,
     pid: Pid,
     uptime: u64,
-    clock_cycle: u64,
+    info: &SystemInfo,
     refresh_kind: ProcessRefreshKind,
 ) -> Result<(Option<Process>, Pid), ()> {
     let pid = match path.file_name().and_then(|x| x.to_str()).map(Pid::from_str) {
@@ -367,11 +336,10 @@ pub(crate) fn _get_process_data(
             path,
             entry,
             &parts,
-            page_size_kb,
             parent_memory,
             parent_virtual_memory,
             uptime,
-            clock_cycle,
+            info,
             refresh_kind,
         );
         if refresh_kind.disk_usage() {
@@ -389,17 +357,18 @@ pub(crate) fn _get_process_data(
     let parts = parse_stat_file(&data)?;
     let name = parts[1];
 
-    let parent_pid = if proc_list.pid != 0 {
+    let parent_pid = if proc_list.pid.0 != 0 {
         Some(proc_list.pid)
     } else {
         match Pid::from_str(parts[3]) {
-            Ok(p) if p != 0 => Some(p),
+            Ok(p) if p.0 != 0 => Some(p),
             _ => None,
         }
     };
 
-    let start_time = u64::from_str(parts[21]).unwrap_or(0) / clock_cycle;
-    let mut p = Process::new(pid, parent_pid, start_time);
+    // To be noted that the start time is invalid here, it still needs
+    let start_time = u64::from_str(parts[21]).unwrap_or(0) / info.clock_cycle;
+    let mut p = Process::new(pid, parent_pid, start_time, info);
 
     p.stat_file = stat_file;
     get_status(&mut p, parts[2]);
@@ -413,7 +382,7 @@ pub(crate) fn _get_process_data(
         }
     }
 
-    if proc_list.pid != 0 {
+    if proc_list.pid.0 != 0 {
         // If we're getting information for a child, no need to get those info since we
         // already have them...
         p.cmd = proc_list.cmd.clone();
@@ -456,11 +425,10 @@ pub(crate) fn _get_process_data(
         path,
         &mut p,
         &parts,
-        page_size_kb,
         proc_list.memory,
         proc_list.virtual_memory,
         uptime,
-        clock_cycle,
+        info,
         refresh_kind,
     );
     if refresh_kind.disk_usage() {
@@ -474,16 +442,15 @@ fn update_time_and_memory(
     path: &Path,
     entry: &mut Process,
     parts: &[&str],
-    page_size_kb: u64,
     parent_memory: u64,
     parent_virtual_memory: u64,
     uptime: u64,
-    clock_cycle: u64,
+    info: &SystemInfo,
     refresh_kind: ProcessRefreshKind,
 ) {
     {
         // rss
-        entry.memory = u64::from_str(parts[23]).unwrap_or(0) * page_size_kb;
+        entry.memory = u64::from_str(parts[23]).unwrap_or(0) * info.page_size_kb;
         if entry.memory >= parent_memory {
             entry.memory -= parent_memory;
         }
@@ -497,15 +464,14 @@ fn update_time_and_memory(
             u64::from_str(parts[13]).unwrap_or(0),
             u64::from_str(parts[14]).unwrap_or(0),
         );
-        entry.run_time = uptime.saturating_sub(entry.start_time);
+        entry.run_time = uptime.saturating_sub(entry.start_time_without_boot_time);
     }
     refresh_procs(
         entry,
         &path.join("task"),
-        page_size_kb,
         entry.pid,
         uptime,
-        clock_cycle,
+        info,
         refresh_kind,
     );
 }
@@ -513,10 +479,9 @@ fn update_time_and_memory(
 pub(crate) fn refresh_procs(
     proc_list: &mut Process,
     path: &Path,
-    page_size_kb: u64,
     pid: Pid,
     uptime: u64,
-    clock_cycle: u64,
+    info: &SystemInfo,
     refresh_kind: ProcessRefreshKind,
 ) -> bool {
     if let Ok(d) = fs::read_dir(path) {
@@ -535,7 +500,7 @@ pub(crate) fn refresh_procs(
                 }
             })
             .collect::<Vec<_>>();
-        if pid == 0 {
+        if pid.0 == 0 {
             let proc_list = Wrap(UnsafeCell::new(proc_list));
 
             #[cfg(feature = "multithread")]
@@ -546,10 +511,9 @@ pub(crate) fn refresh_procs(
                     if let Ok((p, _)) = _get_process_data(
                         e.as_path(),
                         proc_list.get(),
-                        page_size_kb,
                         pid,
                         uptime,
-                        clock_cycle,
+                        info,
                         refresh_kind,
                     ) {
                         p
@@ -563,15 +527,9 @@ pub(crate) fn refresh_procs(
             let new_tasks = folders
                 .iter()
                 .filter_map(|e| {
-                    if let Ok((p, pid)) = _get_process_data(
-                        e.as_path(),
-                        proc_list,
-                        page_size_kb,
-                        pid,
-                        uptime,
-                        clock_cycle,
-                        refresh_kind,
-                    ) {
+                    if let Ok((p, pid)) =
+                        _get_process_data(e.as_path(), proc_list, pid, uptime, info, refresh_kind)
+                    {
                         updated_pids.push(pid);
                         p
                     } else {
