@@ -1,8 +1,4 @@
-//
-// Sysinfo
-//
-// Copyright (c) 2017 Guillaume Gomez
-//
+// Take a look at the license at the top of the repository in the LICENSE file.
 
 use crate::sys::tools::KeyHandler;
 use crate::{LoadAvg, ProcessorExt};
@@ -20,7 +16,7 @@ use winapi::shared::minwindef::FALSE;
 use winapi::shared::winerror::{ERROR_INSUFFICIENT_BUFFER, ERROR_SUCCESS};
 use winapi::um::handleapi::CloseHandle;
 use winapi::um::pdh::{
-    PdhAddCounterW, PdhAddEnglishCounterA, PdhCloseQuery, PdhCollectQueryData,
+    PdhAddEnglishCounterA, PdhAddEnglishCounterW, PdhCloseQuery, PdhCollectQueryData,
     PdhCollectQueryDataEx, PdhGetFormattedCounterValue, PdhOpenQueryA, PdhRemoveCounter,
     PDH_FMT_COUNTERVALUE, PDH_FMT_DOUBLE, PDH_HCOUNTER, PDH_HQUERY,
 };
@@ -164,7 +160,7 @@ impl Drop for InternalQuery {
     }
 }
 
-pub struct Query {
+pub(crate) struct Query {
     internal: InternalQuery,
 }
 
@@ -213,14 +209,14 @@ impl Query {
     }
 
     #[allow(clippy::ptr_arg)]
-    pub fn add_counter(&mut self, name: &String, getter: Vec<u16>) -> bool {
+    pub fn add_english_counter(&mut self, name: &String, getter: Vec<u16>) -> bool {
         if self.internal.data.contains_key(name) {
             sysinfo_debug!("Query::add_english_counter: doesn't have key `{:?}`", name);
             return false;
         }
         unsafe {
             let mut counter: PDH_HCOUNTER = std::mem::zeroed();
-            let ret = PdhAddCounterW(self.internal.query, getter.as_ptr(), 0, &mut counter);
+            let ret = PdhAddEnglishCounterW(self.internal.query, getter.as_ptr(), 0, &mut counter);
             if ret == ERROR_SUCCESS as _ {
                 self.internal.data.insert(name.clone(), counter);
             } else {
@@ -244,6 +240,51 @@ impl Query {
     }
 }
 
+pub(crate) struct ProcessorsWrapper {
+    global: Processor,
+    processors: Vec<Processor>,
+}
+
+impl ProcessorsWrapper {
+    pub fn new() -> Self {
+        Self {
+            global: Processor::new_with_values("Total CPU", String::new(), String::new(), 0),
+            processors: Vec::new(),
+        }
+    }
+
+    pub fn global_processor(&self) -> &Processor {
+        &self.global
+    }
+
+    pub fn global_processor_mut(&mut self) -> &mut Processor {
+        &mut self.global
+    }
+
+    pub fn processors(&self) -> &[Processor] {
+        &self.processors
+    }
+
+    fn init_if_needed(&mut self) {
+        if self.processors.is_empty() {
+            let (processors, vendor_id, brand) = super::tools::init_processors();
+            self.processors = processors;
+            self.global.vendor_id = vendor_id;
+            self.global.brand = brand;
+        }
+    }
+
+    pub fn len(&mut self) -> usize {
+        self.init_if_needed();
+        self.processors.len()
+    }
+
+    pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Processor> {
+        self.init_if_needed();
+        self.processors.iter_mut()
+    }
+}
+
 #[doc = include_str!("../../md_doc/processor.md")]
 pub struct Processor {
     name: String,
@@ -323,7 +364,7 @@ fn get_vendor_id_not_great(info: &SYSTEM_INFO) -> String {
 }
 
 #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
-pub fn get_vendor_id_and_brand(info: &SYSTEM_INFO) -> (String, String) {
+pub(crate) fn get_vendor_id_and_brand(info: &SYSTEM_INFO) -> (String, String) {
     #[cfg(target_arch = "x86")]
     use std::arch::x86::__cpuid;
     #[cfg(target_arch = "x86_64")]
@@ -392,11 +433,11 @@ pub fn get_vendor_id_and_brand(info: &SYSTEM_INFO) -> (String, String) {
 }
 
 #[cfg(all(not(target_arch = "x86_64"), not(target_arch = "x86")))]
-pub fn get_vendor_id_and_brand(info: &SYSTEM_INFO) -> (String, String) {
+pub(crate) fn get_vendor_id_and_brand(info: &SYSTEM_INFO) -> (String, String) {
     (get_vendor_id_not_great(info), String::new())
 }
 
-pub fn get_key_used(p: &mut Processor) -> &mut Option<KeyHandler> {
+pub(crate) fn get_key_used(p: &mut Processor) -> &mut Option<KeyHandler> {
     &mut p.key_used
 }
 
@@ -405,7 +446,7 @@ pub fn get_key_used(p: &mut Processor) -> &mut Option<KeyHandler> {
 // If your PC has 64 or fewer logical processors installed, the above code will work fine. However,
 // if your PC has more than 64 logical processors installed, use GetActiveProcessorCount() or
 // GetLogicalProcessorInformation() to determine the total number of logical processors installed.
-pub fn get_frequencies(nb_processors: usize) -> Vec<u64> {
+pub(crate) fn get_frequencies(nb_processors: usize) -> Vec<u64> {
     let size = nb_processors * mem::size_of::<PROCESSOR_POWER_INFORMATION>();
     let mut infos: Vec<PROCESSOR_POWER_INFORMATION> = Vec::with_capacity(nb_processors);
 
@@ -433,7 +474,7 @@ pub fn get_frequencies(nb_processors: usize) -> Vec<u64> {
     }
 }
 
-pub fn get_physical_core_count() -> Option<usize> {
+pub(crate) fn get_physical_core_count() -> Option<usize> {
     // we cannot use the number of processors here to pre calculate the buf size
     // GetLogicalProcessorInformationEx with RelationProcessorCore passed to it not only returns
     // the logical cores but also numa nodes
